@@ -1,12 +1,10 @@
 glmm_final_noRE<-function(y,X,K,Delta_start,steps=1000,family,overdispersion,phi,
                      nue=1,print.iter.final=FALSE,flushit,eps.final=1e-5)
 {
-  
+  #browser()
   ## Print stuff.
   ia <- if(flushit) interactive() else FALSE
   
-  
-  
 N<-length(y)
 lin<-ncol(as.matrix(X))
 Eta<-X%*%Delta_start
@@ -16,11 +14,9 @@ if(is.null(family$multivariate)){
   Mu<-family$linkinv(Eta)
   SigmaInv <- 1/family$variance(Mu)
 }else{
-  Eta_cat <- matrix(Eta, byrow = TRUE, ncol = K)
-  Mu_cat <- family$linkinv(Eta_cat)
-  D <- family$deriv.mat(Mu_cat)
-  SigmaInv <- family$SigmaInv(Mu_cat)
-  Mu <- c(t(Mu_cat))
+  Mu <- family$linkinv(Eta, K)
+  D <- family$deriv.mat(Eta, K)
+  SigmaInv <- family$SigmaInv(Mu, K)
 }
 
 
@@ -47,12 +43,13 @@ if(is.null(family$multivariate)){
   score_vec <- t(Z_alles)%*%((y-Mu)*D*SigmaInv)
   F_gross<-t(Z_alles)%*%(Z_alles*D*SigmaInv*D)
 }else{
-  score_vec <- t(Z_alles)%*%(D%*%(SigmaInv%*%(y-Mu)))
-  F_gross<-t(Z_alles)%*%(D%*%(SigmaInv%*%(t(D)%*%Z_alles)))
+  score_vec<-RcppEigenProd1(Z_alles, D, SigmaInv, y, Mu)
+  W_opt <- RcppEigenProd2(D, SigmaInv)
+  F_gross <- t(Z_alles)%*%(W_opt%*%Z_alles)
 }
 
 InvFisher<-try(chol2inv(chol(F_gross)),silent=TRUE)
-if(class(InvFisher)=="try-error")
+if(inherits(InvFisher, "try-error"))
 InvFisher<-solve(F_gross)  
 
 half.index<-0
@@ -74,28 +71,29 @@ if(is.null(family$multivariate)){
   Mu<-family$linkinv(Eta)
   SigmaInv <- 1/family$variance(Mu)
 }else{
-  Eta_cat <- matrix(Eta, byrow = TRUE, ncol = K)
-  Mu_cat <- family$linkinv(Eta_cat)
-  D <- family$deriv.mat(Mu_cat)
-  SigmaInv <- family$SigmaInv(Mu_cat)
-  Mu <- c(t(Mu_cat))
+  Mu <- family$linkinv(Eta, K)
+  D <- family$deriv.mat(Eta, K)
+  SigmaInv <- family$SigmaInv(Mu, K)
 }
 
+
 if(is.null(family$multivariate)){
-  D <- as.vector(D);SigmaInv <- as.vector(SigmaInv)
+  D <- drop(D);SigmaInv <- drop(SigmaInv)
   score_vec <- t(Z_alles)%*%((y-Mu)*D*SigmaInv)
   F_gross<-t(Z_alles)%*%(Z_alles*D*SigmaInv*D)
 }else{
-  score_vec <- t(Z_alles)%*%(D%*%(SigmaInv%*%(y-Mu)))
-  F_gross<-t(Z_alles)%*%(D%*%(SigmaInv%*%(t(D)%*%Z_alles)))
+  score_vec<-RcppEigenProd1(Z_alles, D, SigmaInv, y, Mu)
+  W_opt <- RcppEigenProd2(D, SigmaInv)
+  F_gross <- t(Z_alles)%*%(W_opt%*%Z_alles)
 }
 
+
 InvFisher<-try(chol2inv(chol(F_gross)),silent=TRUE)
 
-  if(class(InvFisher)=="try-error")
+  if(inherits(InvFisher, "try-error"))
   InvFisher<-try(solve(F_gross),silent=TRUE)  
 
-  if(class(InvFisher)=="try-error")
+  if(inherits(InvFisher, "try-error"))
   {
     half.index<-half.index+1  
   }else{
@@ -140,27 +138,27 @@ if(is.null(family$multivariate)){
   Mu<-family$linkinv(Eta)
   SigmaInv <- 1/family$variance(Mu)
 }else{
-  Eta_cat <- matrix(Eta, byrow = TRUE, ncol = K)
-  Mu_cat <- family$linkinv(Eta_cat)
-  D <- family$deriv.mat(Mu_cat)
-  SigmaInv <- family$SigmaInv(Mu_cat)
-  Mu <- c(t(Mu_cat))
+  Mu <- family$linkinv(Eta, K)
+  D <- family$deriv.mat(Eta, K)
+  SigmaInv <- family$SigmaInv(Mu, K)
 }
 
 
 if(is.null(family$multivariate)){
-  D <- as.vector(D);SigmaInv <- as.vector(SigmaInv)
+  D <- drop(D);SigmaInv <- drop(SigmaInv)
   score_vec <- t(Z_alles)%*%((y-Mu)*D*SigmaInv)
   F_gross<-t(Z_alles)%*%(Z_alles*D*SigmaInv*D)
 }else{
-  score_vec <- t(Z_alles)%*%(D%*%(SigmaInv%*%(y-Mu)))
-  F_gross<-t(Z_alles)%*%(D%*%(SigmaInv%*%(t(D)%*%Z_alles)))
+  score_vec<-RcppEigenProd1(Z_alles, D, SigmaInv, y, Mu)
+  W_opt <- RcppEigenProd2(D, SigmaInv)
+  F_gross <- t(Z_alles)%*%(W_opt%*%Z_alles)
 }
 
+
 InvFisher<-try(chol2inv(chol(F_gross)),silent=TRUE)
-  if(class(InvFisher)=="try-error")
+  if(inherits(InvFisher, "try-error"))
   InvFisher<-try(solve(F_gross),silent=TRUE)  
-  if(class(InvFisher)=="try-error")
+  if(inherits(InvFisher, "try-error"))
   {
     half.index<-half.index+1  
   }else{
@@ -183,12 +181,11 @@ if(finish ||  finish2)
 opt<-l
 
   if(is.null(family$multivariate)){
-  W_opt <- D*SigmaInv*D
-  FinalHat<-(Z_alles*sqrt(W_opt))%*%InvFisher%*%t(Z_alles*sqrt(W_opt))
+    W_opt <- D*SigmaInv*D
+    FinalHat<-(Z_alles*sqrt(W_opt))%*%InvFisher%*%t(Z_alles*sqrt(W_opt))
   }else{
-    W_opt <- D%*%(SigmaInv%*%t(D))
-    W_inv_t <- chol(W_opt)
-    FinalHat<-W_inv_t%*%(Z_alles%*%(InvFisher%*%(t(Z_alles)%*%t(W_inv_t))))
+    W_inv_t <- RcppEigenSpChol(W_opt)
+    FinalHat <- RcppEigenProd3(W_inv_t, Z_alles, InvFisher)
   }
 
   complexity<-sum(diag(FinalHat))
